Index: branches/new_class_id/src/lib/util/debug_buffer.h
===================================================================
--- branches/new_class_id/src/lib/shell/shell_buffer.h	(revision 9692)
+++ branches/new_class_id/src/lib/util/debug_buffer.h	(revision 9861)
@@ -1,33 +1,30 @@
 /*!
  * @file shell_buffer.h
  * @brief The Shell buffer Tasks
  * @see debug.h
 */
 
-#ifndef _SHELL_BUFFER_H
-#define _SHELL_BUFFER_H
+#ifndef _DEBUG_BUFFER_H
+#define _DEBUG_BUFFER_H
 
 #include <string>
 #include <list>
-#include <stdarg.h>
 
-#define      SHELL_BUFFER_SIZE       16384         //!< The Size of the input-buffers (should be large enough to carry any kind of input)
+#define      DEBUG_BUFFER_SIZE       16384         //!< The Size of the input-buffers (should be large enough to carry any kind of input)
 
-namespace OrxShell
-{
   //! A class handling output from orxonox via debug.h
   /**
    * the ShellBuffer redirects output from PRINTF(x) to the Shell and STDOUT
    * the ShellBuffer is a front-filling queue of limited length, that has the
    * youngest added Entry at the beginning, and the oldest at the end.
    */
-  class ShellBuffer
+  class DebugBuffer
   {
   public:
-    virtual ~ShellBuffer();
+    virtual ~DebugBuffer();
     /** @returns a Pointer to the only object of this Class */
-    inline static ShellBuffer* getInstance() { if (!ShellBuffer::singletonRef) ShellBuffer::singletonRef = new ShellBuffer();  return ShellBuffer::singletonRef; };
+    inline static DebugBuffer* getInstance() { if (!DebugBuffer::singletonRef) DebugBuffer::singletonRef = new DebugBuffer();  return DebugBuffer::singletonRef; };
     /** @returns true if this class is instanciated, false otherwise */
-    inline static bool isInstanciated() { return (ShellBuffer::singletonRef == NULL)?false:true; };
+    inline static bool isInstanciated() { return (DebugBuffer::singletonRef == NULL)?false:true; };
 
     static void addBufferLineStatic(const char* line, ...);
@@ -41,5 +38,5 @@
     /** @returns the List of stings from the Buffer */
     const std::list<std::string>& getBuffer() const { return this->buffer; };
     /** @returns the Count of lines processed by the Shell. */
     inline unsigned long getLineCount() const { return this->lineCount; };
     /** @returns the Current Buffer Size. */
@@ -49,20 +46,18 @@
 
   private:
-    ShellBuffer();
+    DebugBuffer();
 
   private:
-    static ShellBuffer*           singletonRef;                       //!< The singleton-reference to the only memeber of this class.
-    unsigned int                  maxBufferSize;                         //!< The Size of the buffer
+    static DebugBuffer*           singletonRef;                       //!< The singleton-reference to the only memeber of this class.
+    unsigned int                  maxBufferSize;                      //!< The Size of the buffer
 
-    std::string                   keepBuffer;                         //!< a BUFFER to have multi-non-newLine commands be copied into the shell.
+    std::string                   keepBuffer;                         //!< a BUFFER to have multi-non-newLine commands be copied into the debug.
 
     unsigned long                 lineCount;                          //!< how many Lines have been written out so far.
 
     // The Beginning of buffer (buffer.front()) is the last added line.
-    static char                   bufferArray[SHELL_BUFFER_SIZE];     //!< a BUFFER for fast writing
+    static char                   bufferArray[DEBUG_BUFFER_SIZE];     //!< a BUFFER for fast writing
     static std::list<std::string> buffer;                             //!< A list of stored char-arrays(strings) to store the history
   };
 
-}
-
-#endif /* _SHELL_BUFFER_H */
+#endif /* _DEBUG_BUFFER_H */
@@ -1,33 +1,30 @@
 /*!
- * @file shell_buffer.h
- * @brief The Shell buffer Tasks
+ * @file debug_buffer.h
+ * @brief The Debug buffer Tasks
  * @see debug.h
 */
@@ -1,33 +1,30 @@
   //! A class handling output from orxonox via debug.h
   /**
-   * the ShellBuffer redirects output from PRINTF(x) to the Shell and STDOUT
-   * the ShellBuffer is a front-filling queue of limited length, that has the
+   * the DebugBuffer redirects output from PRINTF(x) to the Debug and STDOUT
+   * the DebugBuffer is a front-filling queue of limited length, that has the
    * youngest added Entry at the beginning, and the oldest at the end.
    */
@@ -41,5 +38,5 @@
     /** @returns the List of stings from the Buffer */
     const std::list<std::string>& getBuffer() const { return this->buffer; };
-    /** @returns the Count of lines processed by the Shell. */
+    /** @returns the Count of lines processed by the Debug. */
     inline unsigned long getLineCount() const { return this->lineCount; };
     /** @returns the Current Buffer Size. */
